@@ -1,11 +1,16 @@
 from subprocess import DEVNULL, run
 import warnings
 
+import pkg_resources
+
 from bcpandas.main import SqlCreds, to_sql
 from bcpandas.utils import bcp
 
 name = "bcpandas"
-__version__ = "2.0.0"
+try:
+    __version__ = pkg_resources.get_distribution(__name__).version
+except Exception:
+    __version__ = "unknown"
 
 
 # BCP check
