@@ -7,12 +7,14 @@ Created on Sat Aug  3 23:07:15 2019
 import csv
 import logging
 import os
+from pathlib import Path
 from textwrap import dedent
-from typing import Dict, Optional, Union
+from typing import Dict, List, Optional, Union
 from urllib.parse import quote_plus
 
 import pandas as pd
 from pandas.io.sql import SQLDatabase, SQLTable
+import pyodbc
 import sqlalchemy as sa
 
 from bcpandas.constants import (
@@ -44,8 +46,9 @@ class SqlCreds:
     database : str
     username : str, optional
     password : str, optional
-    driver_version : int, default 17
-        The version of the Microsoft ODBC Driver for SQL Server to use
+    driver_version : int, optional
+        The version of the Microsoft ODBC Driver for SQL Server to use. Defaults to the latest
+        version.
     odbc_kwargs : dict of {str, str or int}, optional
         additional keyword arguments, to pass into ODBC connection string,
         such as Encrypted='yes'
@@ -61,7 +64,7 @@ class SqlCreds:
         database: str,
         username: Optional[str] = None,
         password: Optional[str] = None,
-        driver_version: int = 17,
+        driver_version: Optional[int] = None,
         port: int = 1433,
         odbc_kwargs: Optional[Dict[str, Union[str, int]]] = None,
     ):
@@ -69,7 +72,15 @@ class SqlCreds:
         self.database = database
         self.port = port
 
-        self.driver = f"{{ODBC Driver {driver_version} for SQL Server}}"
+        if driver_version is None:
+            all_drivers: List[str] = pyodbc.drivers()
+            driver_candidates: List[str] = [
+                d.split("Driver ")[-1].split(" ")[0] for d in all_drivers if "SQL Server" in d
+            ]
+            new_driver_version: int = max(int(v) for v in driver_candidates if v.isnumeric())
+            self.driver = f"{{ODBC Driver {new_driver_version} for SQL Server}}"
+        else:
+            self.driver = f"{{ODBC Driver {driver_version} for SQL Server}}"
 
         # Append a comma for use in connection strings (optionally blank)
         if port:
@@ -175,7 +186,7 @@ def _create_table(
     creds: SqlCreds,
     df: pd.DataFrame,
     if_exists: str,
-    dtype: dict = None,
+    dtype: Optional[dict] = None,
 ):
     """use pandas' own code to create the table and schema"""
 
@@ -314,15 +325,17 @@ def to_sql(
     schema: str = "dbo",
     index: bool = True,
     if_exists: str = "fail",
-    batch_size: int = None,
+    batch_size: Optional[int] = None,
+    use_tablock: bool = False,
     debug: bool = False,
-    bcp_path: str = None,
-    dtype: dict = None,
+    bcp_path: Optional[str] = None,
+    dtype: Optional[dict] = None,
     process_dest_table: bool = True,
     print_output: bool = True,
-    delimiter: str = None,
-    quotechar: str = None,
+    delimiter: Optional[str] = None,
+    quotechar: Optional[str] = None,
     encoding: Optional[str] = None,
+    work_directory: Optional[Path] = None,
 ):
     """
     Writes the pandas DataFrame to a SQL table or view.
@@ -356,6 +369,9 @@ def to_sql(
 
     batch_size : int, optional
         Rows will be written in batches of this size at a time. By default, BCP sets this to 1000.
+    use_tablock : bool, default False
+        Whether to acquire a table-level lock rather than row-level locks to improve performance.
+        Setting this option allows for larger batch sizes.
     debug : bool, default False
         If True, will not delete the temporary CSV and format files, and will output their location.
     bcp_path : str, default None
@@ -377,6 +393,9 @@ def to_sql(
         Optional quotechar to use, otherwise will use the result of `constants.get_quotechar`
     encoding: str, default None
         Optional encoding to use for writing the BCP data-file. Defaults to `utf-8`.
+    work_directory: pathlib.Path, default None
+        Optional directory where temporary files are written to. If not provided, defaults to the
+        system-default for temporary files.
 
     Notes
     -----
@@ -397,7 +416,7 @@ def to_sql(
     _quotechar = get_quotechar(df) if quotechar is None else quotechar
 
     # save to temp path
-    csv_file_path = get_temp_file()
+    csv_file_path = get_temp_file(work_directory)
     # replace bools with 1 or 0, this is what pandas native does when writing to SQL Server
     df.replace({True: 1, False: 0}).to_csv(
         path_or_buf=csv_file_path,
@@ -414,7 +433,7 @@ def to_sql(
     logger.debug(f"Saved dataframe to temp CSV file at {csv_file_path}")
 
     # build format file
-    fmt_file_path = get_temp_file()
+    fmt_file_path = get_temp_file(work_directory)
 
     sql_item_exists = _sql_item_exists(
         sql_type=sql_type, schema=schema, table_name=table_name, creds=creds
@@ -458,6 +477,7 @@ def to_sql(
             sql_type=sql_type,
             schema=schema,
             batch_size=batch_size,
+            use_tablock=use_tablock,
             bcp_path=bcp_path,
         )
     finally:
