@@ -144,7 +144,11 @@ def test_tosql_full_bcp_path(bcp_path, sql_creds):
         ),
         pytest.param(
             pd.DataFrame(
-                {"col1": [1.5, 2.5, 3.5, 4.5], "col2": [1, 2, 3, 4], "col3": ["a", None, "c", None]}
+                {
+                    "col1": [1.5, 2.5, 3.5, 4.5],
+                    "col2": [1, 2, 3, 4],
+                    "col3": ["a", None, "c", None],
+                }
             ),
             id="None_last_col",
         ),
@@ -264,6 +268,38 @@ def test_batch_size_param(sql_creds, batch_size):
         )
 
 
+def test_use_tablock_param(sql_creds):
+    """
+    Test ingest is successful when use_tablock param used.
+    """
+    to_sql(
+        df=pd.DataFrame({"col1": [1.5]}),
+        table_name="some_table",
+        creds=sql_creds,
+        if_exists="replace",
+        index=False,
+        sql_type="table",
+        use_tablock=True,
+    )
+    assert sql_creds.engine.execute("SELECT * FROM some_table").first()[0] == 1.5
+
+
+def test_custom_work_directory(sql_creds):
+    """
+    Test the work directory parameters.
+    """
+    to_sql(
+        df=pd.DataFrame({"col1": [1.5]}),
+        table_name="some_table",
+        creds=sql_creds,
+        if_exists="replace",
+        index=False,
+        sql_type="table",
+        work_directory=Path("."),
+    )
+    assert sql_creds.engine.execute("SELECT * FROM some_table").first()[0] == 1.5
+
+
 @pytest.mark.usefixtures("database")
 class _BaseToSql:
     sql_type = "table"
@@ -314,7 +350,8 @@ class TestToSqlColumnScenarios(_BaseToSql):
             sql=f"SELECT * FROM {self.schema_name}.{self.table_name}", con=self.sql_creds.engine
         )
         expected = prep_df_for_comparison(
-            df=pd.concat([self.df, df_modified], axis=0, ignore_index=True, sort=False), index=False
+            df=pd.concat([self.df, df_modified], axis=0, ignore_index=True, sort=False),
+            index=False,
         )
         assert_frame_equal(expected, actual)
 
