@@ -5,7 +5,6 @@ Created on Sat Aug  3 23:07:15 2019
 """
 
 import logging
-import os
 from pathlib import Path
 import random
 import shlex
@@ -39,16 +38,17 @@ logger = logging.getLogger(__name__)
 def bcp(
     sql_item: str,
     direction: str,
-    flat_file: str,
+    flat_file: Path,
     creds,
     print_output: bool,
     sql_type: str = "table",
     schema: str = "dbo",
-    format_file_path: str = None,
-    batch_size: int = None,
-    col_delimiter: str = None,
-    row_terminator: str = None,
-    bcp_path: Union[str, Path] = None,
+    format_file_path: Optional[Path] = None,
+    batch_size: Optional[int] = None,
+    use_tablock: bool = False,
+    col_delimiter: Optional[str] = None,
+    row_terminator: Optional[str] = None,
+    bcp_path: Optional[Union[str, Path]] = None,
 ):
     """
     See https://docs.microsoft.com/en-us/sql/tools/bcp-utility
@@ -69,7 +69,7 @@ def bcp(
     if creds.with_krb_auth:
         auth = ["-T"]
     else:
-        auth = ["-U", creds.username, "-P", creds.password]
+        auth = ["-U", quote_this(creds.username), "-P", quote_this(creds.password)]
 
     # prepare SQL item string
     if sql_type == QUERY:
@@ -78,14 +78,19 @@ def bcp(
     else:
         sql_item_string = f"{schema}.{sql_item}"
 
+    if creds.port is not None and creds.port != 1433:
+        server = f"{creds.server},{creds.port}"
+    else:
+        server = creds.server
+
     # construct BCP command
     bcp_command = [
         "bcp" if bcp_path is None else quote_this(str(bcp_path)),
         sql_item_string,
         direc,
-        flat_file,
+        str(flat_file),
         "-S",
-        creds.server,
+        server,
         "-d",
         creds.database,
         "-q",  # Executes the SET QUOTED_IDENTIFIERS ON statement, needed for Azure SQL DW
@@ -94,9 +99,12 @@ def bcp(
     if batch_size:
         bcp_command += ["-b", str(batch_size)]
 
+    if use_tablock:
+        bcp_command += ["-h", "TABLOCK"]
+
     # formats
-    if direc == IN:
-        bcp_command += ["-f", format_file_path]
+    if direc == IN and format_file_path is not None:
+        bcp_command += ["-f", str(format_file_path)]
     elif direc in (OUT, QUERYOUT):
         bcp_command += [
             "-c",  # marking as character data, not Unicode (maybe make as param?)
@@ -116,15 +124,15 @@ def bcp(
         raise BCPandasException(f"Bcp command failed with exit code {ret_code}")
 
 
-def get_temp_file() -> str:
+def get_temp_file(directory: Optional[Path] = None) -> Path:
     """
     Returns full path to a temporary file without creating it.
     """
-    tmp_dir = tempfile.gettempdir()
-    file_path = os.path.join(
-        tmp_dir, "".join(random.choices(string.ascii_letters + string.digits, k=21))
-    )
-    return file_path
+    if directory is None:
+        tmp_dir = Path(tempfile.gettempdir())
+    else:
+        tmp_dir = directory
+    return tmp_dir / "".join(random.choices(string.ascii_letters + string.digits, k=21))
 
 
 def _escape(input_string: str) -> str:
@@ -230,7 +238,7 @@ def run_cmd(cmd: List[str], *, print_output: bool) -> int:
         with_shell = False
     else:
         with_shell = True
-        cmd = " ".join(cmd)  # type: ignore
+        cmd = " ".join(cmd).replace("\\", "\\\\")  # type: ignore
     proc = Popen(
         cmd,
         stdout=PIPE,
